The xcookie Module
==================

|GithubActions| |ReadTheDocs| |Pypi| |Downloads| |Codecov|


The ``xcookie`` module. A helper for templating python projects.

+------------------+----------------------------------------------+
| Read the docs    | https://xcookie.readthedocs.io               |
+------------------+----------------------------------------------+
| Github           | https://github.com/Erotemic/xcookie          |
+------------------+----------------------------------------------+
| Pypi             | https://pypi.org/project/xcookie             |
+------------------+----------------------------------------------+


.. |CircleCI| image:: https://circleci.com/gh/Erotemic/xcookie.svg?style=svg
    :target: https://circleci.com/gh/Erotemic/xcookie

.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/github/Erotemic/xcookie?branch=main&svg=True
   :target: https://ci.appveyor.com/project/Erotemic/xcookie/branch/main

.. |Codecov| image:: https://codecov.io/github/Erotemic/xcookie/badge.svg?branch=main&service=github
   :target: https://codecov.io/github/Erotemic/xcookie?branch=main

.. |Pypi| image:: https://img.shields.io/pypi/v/xcookie.svg
   :target: https://pypi.python.org/pypi/xcookie

.. |Downloads| image:: https://img.shields.io/pypi/dm/xcookie.svg
   :target: https://pypistats.org/packages/xcookie

.. |ReadTheDocs| image:: https://readthedocs.org/projects/xcookie/badge/?version=latest
    :target: http://xcookie.readthedocs.io/en/latest/

.. |CodeQuality| image:: https://api.codacy.com/project/badge/Grade/4d815305fc014202ba7dea09c4676343   
    :target: https://www.codacy.com/manual/Erotemic/xcookie?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Erotemic/xcookie&amp;utm_campaign=Badge_Grade

.. |GithubActions| image:: https://github.com/Erotemic/xcookie/actions/workflows/tests.yml/badge.svg?branch=main
    :target: https://github.com/Erotemic/xcookie/actions?query=branch%3Amain
